<?php

namespace Drupal\search_api_elasticsearch_stopwords\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\elasticsearch_connector\Event\PrepareIndexMappingEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class Elastic search mapping subscriber.
 *
 * @package Drupal\search_api_elasticsearch_stopwords\EventSubscriber
 */
class PrepareIndexMappingSubscriber implements EventSubscriberInterface {

  /**
   * The stopwords config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $stopwordsSettings;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->stopwordsSettings = $config_factory->get('search_api_elasticsearch_stopwords.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      PrepareIndexMappingEvent::PREPARE_INDEX_MAPPING => 'prepareIndexMapping',
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function prepareIndexMapping(PrepareIndexMappingEvent $event) {
    if ($this->stopwordsSettings->get('enable')) {
      $mappingParams = $event->getIndexMappingParams();
      if (isset($mappingParams['type'])) {
        $indexKey = $mappingParams['type'];
        foreach ($mappingParams['body'][$indexKey]['properties'] as $key => $property) {
          if ($property['type'] === 'text') {
            $mappingParams['body'][$indexKey]['properties'][$key]['analyzer'] = $mappingParams['body'][$indexKey]['properties'][$key]['analyzer'] ?? 'standard';
            $mappingParams['body'][$indexKey]['properties'][$key]['search_analyzer'] = 'stop';
          }
        }
      }
      else {
        foreach ($mappingParams['body']['properties'] as $key => $property) {
          if ($property['type'] === 'text') {
            $mappingParams['body']['properties'][$key]['analyzer'] = $mappingParams['body']['properties'][$key]['analyzer'] ?? 'standard';
            $mappingParams['body']['properties'][$key]['search_analyzer'] = 'stop';
          }
        }
      }
      $event->setIndexMappingParams($mappingParams);
    }
  }

}
