<?php

namespace Drupal\search_api_elasticsearch_stopwords\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\elasticsearch_connector\Event\PrepareIndexEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class Prepare Index Subscriber.
 *
 * @package Drupal\search_api_elasticsearch_stopwords\EventSubscriber
 */
class PrepareIndexSubscriber implements EventSubscriberInterface {

  /**
   * The stopwords config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $stopwordsSettings;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->stopwordsSettings = $config_factory->get('search_api_elasticsearch_stopwords.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      PrepareIndexEvent::PREPARE_INDEX => 'prepareIndex',
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getStopWords() {
    $stop_words = explode(',', $this->stopwordsSettings->get('stopwords') ?? '');
    return array_map('trim', $stop_words);
  }

  /**
   * {@inheritdoc}
   */
  public function prepareIndex(PrepareIndexEvent $event) {
    if ($this->stopwordsSettings->get('enable')) {
      $indexConfig = $event->getIndexConfig();
      $indexConfig["body"]["settings"]["index"] = [
        "analysis" => [
          "analyzer" => [
            "stop" => [
              "tokenizer" => "whitespace",
              "filter" => [
                "stop",
              ],
            ],
          ],
          "filter" => [
            "stop" => [
              "type" => "stop",
              "ignore_case" => TRUE,
              "stopwords" => $this->getStopWords(),
            ],
          ],
        ],
      ];
      $event->setIndexConfig($indexConfig);
    }
  }

}
