<?php

namespace Drupal\search_api_elasticsearch_stopwords\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Search API Elasticsearch Stopwords.
 */
class SearchApiElasticsearchStopWordsSettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'search_api_elasticsearch_stopwords.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'search_api_elasticsearch_stopwords_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable stopwords'),
      '#default_value' => $config->get('enable'),
      '#description' => $this->t('Change of this option requires index removal and reindexing.'),
    ];

    $form['stopwords'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Stopwords'),
      '#default_value' => $config->get('stopwords'),
      '#description' => $this->t('Enter stopwords separated by comma'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable(static::SETTINGS)
      ->set('enable', $form_state->getValue('enable'))
      ->save();

    $this->configFactory->getEditable(static::SETTINGS)
      ->set('stopwords', $form_state->getValue('stopwords'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
